@@ -336,7 +336,7 @@ def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,maxro
     return val
 
 def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependentvariable,independentvariables,
-                            consumerid,producerid,companyname,partition=-1,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
+                            consumerid,producerid,companyname,maxrows=50,partition=-1,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
 
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(dependentvariable)==0 or
         len(independentvariables)==0 or len(companyname)==0 or len(consumerid)==0 or len(producerid)==0):
@@ -344,7 +344,7 @@ def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependent
         
     value=("createtrainingdata?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto="+produceto +
            "&dependentvariable="+dependentvariable+"&independentvariables="+independentvariables +
-           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&partition="+str(partition)+"&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) +"&maxrows=" + str(maxrows) + "&partition="+str(partition)+"&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
@@ -399,12 +399,13 @@ def vipercreateconsumergroup(vipertoken,host,port,topic,groupname,companyname,co
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperconsumergroupconsumefromtopic(vipertoken,host,port,topic,consumerid,groupid,companyname,partition=-1,enabletls=1,delay=1000,offset=-1,brokerhost='',brokerport=-999,microserviceid=''):
+def viperconsumergroupconsumefromtopic(vipertoken,host,port,topic,consumerid,groupid,companyname,partition=-1,enabletls=1,delay=1000,offset=-1,
+                                       rollbackoffset=0,brokerhost='',brokerport=-999,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(companyname)==0 or len(consumerid)==0 or len(groupid)==0):
          return "Please enter host,port,vipertoken,consumerid,companyname,groupid"
         
     value=("consumergroupconsumefromtopic?vipertoken="+vipertoken + "&topic="+topic + "&consumerid="+consumerid +
-        "&partition=" + str(partition) +  "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost+"&brokerport="+str(brokerport) +"&offset="+str(offset) +"&companyname="+companyname+"&groupid="+groupid)
+        "&partition=" + str(partition) +  "&delay=" + str(delay) + "&rollbackoffset=" + str(rollbackoffset) + "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost+"&brokerport="+str(brokerport) +"&offset="+str(offset) +"&companyname="+companyname+"&groupid="+groupid)
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
